# n2yo-aio

[![Build Status](https://drone.facorazza.com/api/badges/facorazza/n2yo-aio/status.svg)](https://drone.facorazza.com/facorazza/n2yo-aio)

Asynchronous Python wrapper for the N2YO API.

## Installation
```
python3 -m pip install n2yo-aio
```

### Credits
> Based on [n2yo](https://github.com/circuitqed/n2yo)
